@@ -63,6 +63,9 @@ def parse_documents(
     accepted_document_types: list[FileType],
     synthesizer_class: Type[Synthesizer],
     parse_fn: Callable[[str, Path, Path, Type[Synthesizer], Path, Path], str],
+    num_outputs_per_document: int,
+    max_fonts: int = None,
+    max_pages: int = None,
     num_processes: int = max(1, multiprocessing.cpu_count() - 1),
     num_documents: int = None,
 ):
@@ -77,6 +80,9 @@ def parse_documents(
         _parse_fn = partial(
             parse_fn,
             synthesizer_class=synthesizer_class,
+            max_fonts=max_fonts,
+            max_pages=max_pages,
+            num_outputs_per_document=num_outputs_per_document,
             dst_dir=dst_dir,
             tmp_dir=Path(tmp_dir),
         )
