@@ -37,6 +37,11 @@ class Font:
             for k, v in unicode_map.cid2unichr.items():
                 reverse_lookup[v] = k
 
+        # Whitespace will sometimes be encoded as soft-hyphen (173), which does not look correct in the output PDF
+        whitespace = ' '
+        if reverse_lookup.get(whitespace) == 173:
+            reverse_lookup[whitespace] = ord(whitespace)
+
         return reverse_lookup
 
 
